package com.glxp.sale.admin.thread;

import com.glxp.sale.admin.constant.ConstantStatus;
import com.glxp.sale.admin.controller.inout.utils.ContrastErpUtil;
import com.glxp.sale.admin.controller.inout.utils.DataTransUtil;
import com.glxp.sale.admin.controller.inout.utils.InoutUtils;
import com.glxp.sale.admin.entity.param.SystemParamConfigEntity;
import com.glxp.sale.admin.entity.inout.ErpOrderEntity;
import com.glxp.sale.admin.entity.inout.OrderEntity;
import com.glxp.sale.admin.entity.inout.WarehouseEntity;
import com.glxp.sale.admin.httpclient.ErpOrderClient;
import com.glxp.sale.admin.req.inout.CommitRequest;
import com.glxp.sale.admin.req.inout.OrderFilterRequest;
import com.glxp.sale.admin.req.inout.PostOrderRequest;
import com.glxp.sale.admin.req.inout.WarehouseQueryRequest;
import com.glxp.sale.admin.req.param.SystemParamConfigRequest;
import com.glxp.sale.admin.service.basic.UdiInfoService;
import com.glxp.sale.admin.service.basic.UdiRelevanceService;
import com.glxp.sale.admin.service.param.SystemParamConfigService;
import com.glxp.sale.admin.service.inout.CodesService;
import com.glxp.sale.admin.service.inout.CodesTempService;
import com.glxp.sale.admin.service.inout.OrderDetailService;
import com.glxp.sale.admin.service.inout.OrderService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

@Service
public class IoTransInoutService {

    private static final Logger logger = LoggerFactory.getLogger(IoTransInoutService.class);
    @Resource
    private CodesService codesService;
    @Resource
    private OrderService orderService;
    @Resource
    private OrderDetailService orderDetailService;
    @Resource
    UdiRelevanceService udiRelevanceService;
    @Resource
    private UdiInfoService udiInfoService;
    @Value("${UDI_SERVER_URL}")
    private String udiUrl;


    @Resource
    private CodesTempService codesTempService;
    @Autowired
    private SystemParamConfigService systemParamConfigService;

    @Async
    public void creatOrderWeb(PostOrderRequest postOrderRequest) {
        List<PostOrderRequest.PostOrder> postOrders = postOrderRequest.getPostOrder();
        if (postOrders != null && postOrders.size() > 0) {
            for (int i = 0; i < postOrders.size(); i++) {
                PostOrderRequest.PostOrder postOrder = postOrders.get(i);
                List<WarehouseEntity> warehouseEntityList = postOrder.getCodes();
                if (warehouseEntityList != null && warehouseEntityList.size() > 0) {
                    if (StringUtils.isNotBlank(postOrderRequest.getOldOrderId())) {
                        orderService.deleteById(postOrderRequest.getOldOrderId());
                        orderDetailService.deleteByOrderId(postOrderRequest.getOldOrderId());
                    }
                    WarehouseEntity warehouseEntity = warehouseEntityList.get(0);
                    String orderId = System.currentTimeMillis() + i + "";
                    OrderEntity orderSaveRequest = new OrderEntity();
                    orderSaveRequest.setId(orderId);
                    if (warehouseEntity.getActDate() != null) {
                        orderSaveRequest.setActDate(warehouseEntity.getActDate());
                    }
                    orderSaveRequest.setAction(warehouseEntity.getAction());
                    orderSaveRequest.setActor(warehouseEntity.getActor());
                    orderSaveRequest.setCorpOrderId(warehouseEntity.getCorpOrderId());
                    orderSaveRequest.setFromCorpId(warehouseEntity.getFromCorpId());
                    orderSaveRequest.setMainAction(warehouseEntity.getMainAction());
                    orderSaveRequest.setFromCorp(warehouseEntity.getFromCorp());
                    orderSaveRequest.setFromType("网页端");
                    orderSaveRequest.setStatus(postOrderRequest.getSubmitType() == 0 ?
                            ConstantStatus.ORDER_STATUS_PROCESS : ConstantStatus.ORDER_STATUS_TEMP_SAVE);
                    orderSaveRequest.setExportStatus(ConstantStatus.ORDER_EXPORT_UN);
                    orderSaveRequest.setStockCheckFk(postOrder.getStockIdFk());
                    orderSaveRequest.setContrastStatus(ConstantStatus.ORDER_CHECK_UN);
                    orderSaveRequest.setSignStatus(ConstantStatus.ORDER_SIGN_UN);
                    List<String> docidsList = postOrder.getErpOrders();
                    String docidStr = "";
                    if (docidsList != null) {
                        for (String key : docidsList) {
                            docidStr = docidStr + "," + key;
                        }
                        if (docidStr.length() > 1) {
                            docidStr = docidStr.substring(1);
                            orderSaveRequest.setErpFk(docidStr);
                        }
                    }
                    orderService.insertOrder(orderSaveRequest);
                    for (int index = 0; index < warehouseEntityList.size(); index++) {
                        warehouseEntityList.get(index).setOrderId(orderId);
                    }
                    codesTempService.insertCodesTemp(warehouseEntityList);
                }
            }
        }
    }

    //生成订单，插入零时表
    @Async
    public void creatOrder(PostOrderRequest postOrderRequest) {
        List<PostOrderRequest.PostOrder> postOrders = postOrderRequest.getPostOrder();
        if (postOrders != null && postOrders.size() > 0) {
            for (int i = 0; i < postOrders.size(); i++) {
                PostOrderRequest.PostOrder postOrder = postOrders.get(i);
                List<WarehouseEntity> warehouseEntityList = postOrder.getCodes();
                if (warehouseEntityList != null && warehouseEntityList.size() > 0) {
                    WarehouseEntity warehouseEntity = warehouseEntityList.get(0);
                    String orderId = System.currentTimeMillis() + i + "";
                    OrderEntity orderSaveRequest = new OrderEntity();
                    orderSaveRequest.setId(orderId);
                    if (warehouseEntity.getActDate() != null) {
                        orderSaveRequest.setActDate(warehouseEntity.getActDate());
                    }
                    orderSaveRequest.setAction(warehouseEntity.getAction());
                    orderSaveRequest.setActor(warehouseEntity.getActor());
                    orderSaveRequest.setCorpOrderId(warehouseEntity.getCorpOrderId());
                    orderSaveRequest.setFromCorpId(warehouseEntity.getFromCorpId());
                    orderSaveRequest.setMainAction(warehouseEntity.getMainAction());
                    orderSaveRequest.setFromCorp(warehouseEntity.getFromCorp());
                    orderSaveRequest.setFromType("手持终端");
                    orderSaveRequest.setStatus(ConstantStatus.ORDER_STATUS_PROCESS);
                    orderSaveRequest.setExportStatus(ConstantStatus.ORDER_EXPORT_UN);
                    orderSaveRequest.setStockCheckFk(postOrder.getStockIdFk());
                    orderSaveRequest.setContrastStatus(ConstantStatus.ORDER_CHECK_UN);
                    orderSaveRequest.setSignStatus(ConstantStatus.ORDER_SIGN_UN);
                    List<String> docidsList = postOrder.getErpOrders();
                    String docidStr = "";
                    if (docidsList != null) {
                        for (String key : docidsList) {
                            docidStr = docidStr + "," + key;
                        }
                        if (docidStr.length() > 1) {
                            docidStr = docidStr.substring(1);
                            orderSaveRequest.setErpFk(docidStr);
                        }
                    }
                    orderService.insertOrder(orderSaveRequest);
                    for (int index = 0; index < warehouseEntityList.size(); index++) {
                        warehouseEntityList.get(index).setOrderId(orderId);
                    }
                    codesTempService.insertCodesTemp(warehouseEntityList);
                }
            }
        }
    }

    //查找等待处理单据，转入正式表
    @Async
    public void transInout() {
        OrderFilterRequest orderFilterRequest = new OrderFilterRequest();
        orderFilterRequest.setStatus(ConstantStatus.ORDER_STATUS_PROCESS);
        List<OrderEntity> orderEntities = orderService.findAllOrders(orderFilterRequest);
        for (int i = 0; i < orderEntities.size(); i++) {
            OrderEntity orderEntity = orderEntities.get(i);
            orderEntity = orderService.findById(orderEntity.getId());
            if (orderEntity.getStatus() == ConstantStatus.ORDER_STATUS_PROCESS) {
                transInout(orderEntity);
            }

        }
    }

    public void transInout(OrderEntity orderEntity) {

        WarehouseQueryRequest warehouseQueryRequest = new WarehouseQueryRequest();
        warehouseQueryRequest.setOrderId(orderEntity.getId());
        List<WarehouseEntity> filterList = codesTempService.findByOrderId(warehouseQueryRequest);
        List<WarehouseEntity> insertList = new ArrayList<>();

        for (int j = 0; j < filterList.size(); j++) {
            WarehouseEntity warehouseEntity = filterList.get(j);
            String result = new InoutUtils().filterCode(codesService, warehouseEntity, systemParamConfigService);
            if (result == null) {
                insertList.add(warehouseEntity);
            } else {
                orderService.updateOrderStatus(warehouseEntity.getOrderId(), ConstantStatus.ORDER_STATUS_FAIL);
                orderService.updateRemark(orderEntity.getId(), result);
                insertList.clear();
                return;
            }
        }

        if (insertList.size() > 0) {
            codesService.insertWarehouses(insertList);
            WarehouseQueryRequest tempQuery = new WarehouseQueryRequest();
            tempQuery.setOrderId(orderEntity.getId());
            List<WarehouseEntity> temps = codesTempService.findByOrderId(tempQuery);
            if (orderEntity.getErpFk() != null) {
                orderService.updateOrderStatus(orderEntity.getId(), ConstantStatus.ORDER_STATUS_CHECK);
            } else {
                //因为只需用到条码，所以不需要重新读取 TODO
                new InoutUtils(udiUrl).generateConstrastDetail(udiInfoService, udiRelevanceService, orderDetailService, insertList);
                orderService.updateOrderStatus(orderEntity.getId(), ConstantStatus.ORDER_STATUS_SUCCESS);
            }

            List<Long> ids = new ArrayList<>();
            for (WarehouseEntity w : temps) {
                ids.add(w.getId());
            }
            codesTempService.deleteCodesTemp(ids);
            insertList.clear();
        }
    }

    //校验ERP单
    @Async
    public void checkOrder() {

        OrderFilterRequest orderFilterRequest = new OrderFilterRequest();
        orderFilterRequest.setStatus(ConstantStatus.ORDER_STATUS_CHECK);
        List<OrderEntity> orderEntities = orderService.findAllOrders(orderFilterRequest);
        for (int i = 0; i < orderEntities.size(); i++) {
            OrderEntity orderEntity = orderEntities.get(i);
            checkOrder(orderEntity);
        }
    }

    public void checkOrder(OrderEntity orderEntity) {
        orderEntity = orderService.findById(orderEntity.getId());
        List<String> erpIds = DataTransUtil.strToErpList(orderEntity.getErpFk());
        List<WarehouseEntity> transData = codesService.findByReceiptId(orderEntity.getId());
        if (erpIds != null && erpIds.size() > 0) {
            SystemParamConfigRequest systemParamConfigRequest = new SystemParamConfigRequest();
            systemParamConfigRequest.setParamKey("erp_order_query");
            SystemParamConfigEntity systemParamConfigEntityBUMErpQuery = systemParamConfigService.selectByParamKey(systemParamConfigRequest);
            if (systemParamConfigEntityBUMErpQuery == null) {
                orderEntity.setContrastStatus(ConstantStatus.ORDER_CHECK_FAIL);
                orderEntity.setStatus(ConstantStatus.ORDER_STATUS_SUCCESS);
                orderEntity.setRemark("获取ERP出入库单据接口地址未定义");
                orderService.updateOrder(orderEntity);
            } else {
                String erpOrderUrl = systemParamConfigEntityBUMErpQuery.getParamValue();
                List<ErpOrderEntity> cloudErps = new ErpOrderClient(erpOrderUrl).getErpOrder(erpIds,orderEntity.getAction());
                if (cloudErps != null && cloudErps.size() > 0) {
                    List<ErpOrderEntity> returnOrders = new ContrastErpUtil().transErp(cloudErps, udiRelevanceService, orderEntity.getId());
                    ErpOrderEntity temp = returnOrders.get(0);
                    for (int i = 0; i < returnOrders.size(); i++) {
                        if (!temp.getCompanyname().equals(returnOrders.get(i).getCompanyname())) {
                            orderEntity.setContrastStatus(ConstantStatus.ORDER_CHECK_FAIL);
                            orderEntity.setStatus(ConstantStatus.ORDER_STATUS_SUCCESS);
                            orderEntity.setRemark("选择Erp订单往来单位不一致");
                            orderService.updateOrder(orderEntity);
                            return;
                        }
                    }
                    orderDetailService.deleteByOrderId(orderEntity.getId());
                    orderDetailService.insertErpOrders(returnOrders);
                    new ContrastErpUtil(udiUrl).contrastErp(udiInfoService, udiRelevanceService, orderDetailService, orderService, transData, systemParamConfigService);
                } else {
                    orderEntity.setContrastStatus(ConstantStatus.ORDER_CHECK_FAIL);
                    orderEntity.setStatus(ConstantStatus.ORDER_STATUS_SUCCESS);
                    orderEntity.setRemark("获取ERP出入库单据失败");
                    orderService.updateOrder(orderEntity);
                    orderDetailService.deleteByOrderId(orderEntity.getId());
                    new InoutUtils(udiUrl).generateConstrastDetail(udiInfoService, udiRelevanceService, orderDetailService, transData);
                }
            }

        } else {
            orderEntity.setContrastStatus(ConstantStatus.ORDER_CHECK_FAIL);
            orderEntity.setStatus(ConstantStatus.ORDER_STATUS_SUCCESS);
            orderEntity.setRemark("未选入ERP单据进行校验，请手动选择");
            orderService.updateOrder(orderEntity);
        }
    }

    //重码校验错误重新提交
    @Async
    public void repeatCommit(CommitRequest commitRequest) {
        OrderEntity orderEntity = orderService.findById(commitRequest.getOrderId());
        if (orderEntity != null) {
            transInout(orderEntity);
        }
    }

    //重新校验
    @Async
    public void repeatCheck(String orderId) {
        OrderEntity orderEntity = orderService.findById(orderId);
        checkOrder(orderEntity);
    }


}
